Hyperbolic functions
--------------------

Hyperbolic functions
....................

.. autofunction:: mpmath.cosh
.. autofunction:: mpmath.sinh
.. autofunction:: mpmath.tanh
.. autofunction:: mpmath.sech
.. autofunction:: mpmath.csch
.. autofunction:: mpmath.coth


Inverse hyperbolic functions
............................

.. autofunction:: mpmath.acosh
.. autofunction:: mpmath.asinh
.. autofunction:: mpmath.atanh
.. autofunction:: mpmath.asech
.. autofunction:: mpmath.acsch
.. autofunction:: mpmath.acoth
